@@ -7,8 +7,10 @@ import (
 	"encoding/asn1"
 	"errors"
 	"fmt"
-	"github.com/cloudflare/cfrpki/validator/lib"
+	"strings"
 	"time"
+
+	librpki "github.com/cloudflare/cfrpki/validator/lib"
 )
 
 const (
@@ -754,6 +756,9 @@ func ExtractPathManifest(mft *librpki.RPKIManifest) []*PKIFile {
 	for _, file := range mft.Content.FileList {
 		curFile := file.Name
 		path := string(curFile)
+		// GHSA-cqh2-vc2f-q4fh: Prevent file path references to parent
+		// directories.
+		path = strings.ReplaceAll(path, "../", "")
 		item := PKIFile{
 			Type:         DetermineType(path),
 			Path:         path,
@@ -873,6 +878,22 @@ func (sm *SimpleManager) Explore(notMFT bool, addInvalidChilds bool) int {
 			data, err := sm.GetNextFile(file)
 
 			if err == nil && data != nil && sm.StrictHash && data.Sha256 != nil && file.ManifestHash != nil {
+				// Invalidates the Manifests' CA when the manifest is expired
+				if file.Parent != nil && file.Parent.Type == TYPE_MFT {
+					res, ok := sm.ResourceOfPath[file.Parent]
+					if ok && res != nil && res.Resource != nil {
+						cert, ok := res.Resource.(*librpki.RPKIManifest)
+						if ok {
+							if time.Now().After(cert.Content.NextUpdate) || time.Now().Before(cert.Content.ThisUpdate) {
+								sm.InvalidateManifestParent(file, nil)
+							}
+						} else {
+							sm.Log.Debugf("Resource is not a manifest, not invalidating")
+						}
+					} else {
+						sm.Log.Debugf("Could not fetch Parent Resource, not invalidating")
+					}
+				}
 				if bytes.Compare(data.Sha256, file.ManifestHash) != 0 {
 					errHash := NewResourceErrorHash(data.Sha256, file.ManifestHash)
 					errHash.AddFileErrorInfo(file, data)
@@ -889,7 +910,6 @@ func (sm *SimpleManager) Explore(notMFT bool, addInvalidChilds bool) int {
 				}
 
 			}
-
 			if err != nil {
 				sm.reportErrorFile(err, file, data)
 
